==> seedsui-react-3.7.5.tgz: package/es/Swiper/Swiper.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

// require (PrototypeArray.js), 使用了equals
import React, { forwardRef, useRef, useImperativeHandle, useEffect } from 'react';
import Instance from './instance';

var Swiper = forwardRef(function (_ref, ref) {
  var _ref$params = _ref.params,
      params = _ref$params === undefined ? {} : _ref$params,
      _ref$speed = _ref.speed,
      speed = _ref$speed === undefined ? 500 : _ref$speed,
      _ref$activeIndex = _ref.activeIndex,
      activeIndex = _ref$activeIndex === undefined ? 0 : _ref$activeIndex,
      onClick = _ref.onClick,
      onChange = _ref.onChange,
      _ref$wrapperAttribute = _ref.wrapperAttribute,
      wrapperAttribute = _ref$wrapperAttribute === undefined ? {} : _ref$wrapperAttribute,
      _ref$slideAttribute = _ref.slideAttribute,
      slideAttribute = _ref$slideAttribute === undefined ? {} : _ref$slideAttribute,
      _ref$paginationAttrib = _ref.paginationAttribute,
      paginationAttribute = _ref$paginationAttrib === undefined ? {} : _ref$paginationAttrib,
      _ref$prevAttribute = _ref.prevAttribute,
      prevAttribute = _ref$prevAttribute === undefined ? {} : _ref$prevAttribute,
      _ref$nextAttribute = _ref.nextAttribute,
      nextAttribute = _ref$nextAttribute === undefined ? {} : _ref$nextAttribute,
      children = _ref.children,
      containerChildren = _ref.containerChildren,
      others = _objectWithoutProperties(_ref, ['params', 'speed', 'activeIndex', 'onClick', 'onChange', 'wrapperAttribute', 'slideAttribute', 'paginationAttribute', 'prevAttribute', 'nextAttribute', 'children', 'containerChildren']);

  var refEl = useRef(null);
  useImperativeHandle(ref, function () {
    return refEl.current;
  });
  var instance = useRef(null);
  var slides = React.Children.toArray(children);

  useEffect(function () {
    if (!refEl || !refEl.current) return;
    instance.current = new Instance(refEl.current, _extends({}, params, {
      on: _extends({
        slideChange: function slideChange() {
          if (onChange) onChange(instance.current);
        },
        click: function click(e) {
          if (onClick) onClick(instance.current, e);
        }
      }, params.on)
    }));
    refEl.current.instance = instance;
    slideToActiveIndex();
  }, []); // eslint-disable-line

  function beforeUpdate() {
    if (!instance.current && (!slides || !slides.length)) return false;
    return true;
  }
  useEffect(function () {
    if (!beforeUpdate()) return;
    instance.current.update();
    slideToActiveIndex();
  }, slides); // eslint-disable-line

  useEffect(function () {
    slideToActiveIndex();
  }, [activeIndex]); // eslint-disable-line

  function slideToActiveIndex() {
    if (!beforeUpdate()) return;
    var index = 0;
    if (activeIndex > slides.length - 1) {
      index = slides.length - 1;
    } else if (activeIndex < 0) {
      index = 0;
    } else {
      index = activeIndex;
    }
    // 跳转索引与当前索引一致不需要跳转
    if (index === instance.current.activeIndex) return;
    instance.current.slideTo(index, speed);
  }

  // 更新句柄, 防止synchronization模式, 每次组件在render的时候都生成上次render的state、function、effects
  if (instance.current) {
    if (!params.on || !params.on.slideChange) {
      instance.current.off('slideChange');
      instance.current.on('slideChange', function () {
        if (onChange) onChange(instance.current);
      });
    }
    if (!params.on || !params.on.click) {
      instance.current.off('click');
      instance.current.on('click', function (e) {
        if (onClick) onClick(instance.current, e);
      });
    }
  }

  return React.createElement(
    'div',
    _extends({ ref: refEl }, others, { className: 'swiper-container' + (others.className ? ' ' + others.className : '') }),
    React.createElement(
      'div',
      { className: 'swiper-wrapper' },
      slides && slides.map(function (slide, index) {
        return React.createElement(
          'div',
          _extends({}, slideAttribute, { className: 'swiper-slide' + (slideAttribute.className ? ' ' + slideAttribute.className : ''), style: _extends({ overflow: params.zoom ? 'hidden' : '' }, slideAttribute.style || {}), key: index }),
          params.zoom ? React.createElement(
            'div',
            { className: 'swiper-zoom-container' },
            slide
          ) : slide
        );
      })
    ),
    params.pagination && React.createElement('div', _extends({}, paginationAttribute, { className: 'swiper-pagination' + (paginationAttribute.className ? ' ' + paginationAttribute.className : '') })),
    params.navigation && params.navigation.prevEl && React.createElement('div', _extends({}, prevAttribute, { className: 'swiper-button-prev' + (prevAttribute.className ? ' ' + prevAttribute.className : '') })),
    params.navigation && params.navigation.nextEl && React.createElement('div', _extends({}, nextAttribute, { className: 'swiper-button-next' + (nextAttribute.className ? ' ' + nextAttribute.className : '') })),
    containerChildren
  );
});

export default Swiper;

==> seedsui-react-3.7.6.tgz: package/es/Swiper/Swiper.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

// require (PrototypeArray.js), 使用了equals
import React, { forwardRef, useRef, useImperativeHandle, useEffect } from 'react';
import Instance from './instance';

var Swiper = forwardRef(function (_ref, ref) {
  var _ref$params = _ref.params,
      params = _ref$params === undefined ? {} : _ref$params,
      _ref$wrapperAttribute = _ref.wrapperAttribute,
      wrapperAttribute = _ref$wrapperAttribute === undefined ? {} : _ref$wrapperAttribute,
      _ref$paginationAttrib = _ref.paginationAttribute,
      paginationAttribute = _ref$paginationAttrib === undefined ? {} : _ref$paginationAttrib,
      _ref$prevAttribute = _ref.prevAttribute,
      prevAttribute = _ref$prevAttribute === undefined ? {} : _ref$prevAttribute,
      _ref$nextAttribute = _ref.nextAttribute,
      nextAttribute = _ref$nextAttribute === undefined ? {} : _ref$nextAttribute,
      children = _ref.children,
      containerChildren = _ref.containerChildren,
      others = _objectWithoutProperties(_ref, ['params', 'wrapperAttribute', 'paginationAttribute', 'prevAttribute', 'nextAttribute', 'children', 'containerChildren']);

  var refEl = useRef(null);
  useImperativeHandle(ref, function () {
    return refEl.current;
  });
  var instance = useRef(null);

  useEffect(function () {
    if (!refEl || !refEl.current) return;
    instance.current = new Instance('.swiper-container', _extends({}, params));
    refEl.current.instance = instance;
  }, []); // eslint-disable-line

  // 更新句柄, 防止synchronization模式, 每次组件在render的时候都生成上次render的state、function、effects
  if (instance.current) {
    if (!params.on) return;
    for (var eventName in params.on) {
      instance.current.off(eventName);
      instance.current.on(eventName, params.on[eventName]);
    }
  }

  return React.createElement(
    'div',
    _extends({ ref: refEl }, others, { className: 'swiper-container' + (others.className ? ' ' + others.className : '') }),
    React.createElement(
      'div',
      { className: 'swiper-wrapper' },
      children
    ),
    params.pagination && React.createElement('div', _extends({}, paginationAttribute, { className: 'swiper-pagination' + (paginationAttribute.className ? ' ' + paginationAttribute.className : '') })),
    params.navigation && params.navigation.prevEl && React.createElement('div', _extends({}, prevAttribute, { className: 'swiper-button-prev' + (prevAttribute.className ? ' ' + prevAttribute.className : '') })),
    params.navigation && params.navigation.nextEl && React.createElement('div', _extends({}, nextAttribute, { className: 'swiper-button-next' + (nextAttribute.className ? ' ' + nextAttribute.className : '') })),
    containerChildren
  );
});

export default Swiper;
